@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2015 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2019 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -36,8 +36,12 @@ class Rebuild;
 
 class IoState;
 
+class HeaderUpdater;
+
 class DbCellHeader;
 
+class WriteRequest;
+
 }
 
 #endif /* SQUID_FS_ROCK_FORWARD_H */
